@@ -184,6 +184,11 @@ typedef enum
   OSP_TEXTURE_RGB16,
   OSP_TEXTURE_RA16,
   OSP_TEXTURE_R16,
+  OSP_TEXTURE_RA32F,
+  OSP_TEXTURE_RGBA16F,
+  OSP_TEXTURE_RGB16F,
+  OSP_TEXTURE_RA16F,
+  OSP_TEXTURE_R16F,
   // Denotes an unknown texture format, so we can properly initialize parameters
   OSP_TEXTURE_FORMAT_INVALID = 255,
 } OSPTextureFormat;
@@ -194,10 +199,21 @@ typedef enum
     : uint32_t
 #endif
 {
-  OSP_TEXTURE_FILTER_BILINEAR = 0, // default bilinear interpolation
-  OSP_TEXTURE_FILTER_NEAREST // use nearest-neighbor interpolation
+  OSP_TEXTURE_FILTER_LINEAR = 0, // default bilinear interpolation
+  OSP_TEXTURE_FILTER_NEAREST = 1 // use nearest-neighbor interpolation
 } OSPTextureFilter;
 
+// Wrap modes that can be set on 'texture2d' type OSPTexture
+typedef enum
+#if __cplusplus >= 201103L
+    : uint32_t
+#endif
+{
+  OSP_TEXTURE_WRAP_REPEAT,
+  OSP_TEXTURE_WRAP_MIRRORED_REPEAT,
+  OSP_TEXTURE_WRAP_CLAMP_TO_EDGE
+} OSPTextureWrapMode;
+
 // Error codes returned by various API and callback functions
 typedef enum
 #if __cplusplus >= 201103L
@@ -277,7 +293,7 @@ typedef enum
 // OSPRay camera stereo image modes
 typedef enum
 #if __cplusplus >= 201103L
-    : uint8_t
+    : uint32_t
 #endif
 {
   OSP_STEREO_NONE,
@@ -290,7 +306,7 @@ typedef enum
 
 typedef enum
 #if __cplusplus >= 201103L
-    : uint8_t
+    : uint32_t
 #endif
 {
   OSP_SHUTTER_GLOBAL,
@@ -303,7 +319,7 @@ typedef enum
 
 typedef enum
 #if __cplusplus >= 201103L
-    : uint8_t
+    : uint32_t
 #endif
 {
   OSP_ROUND,
@@ -315,7 +331,18 @@ typedef enum
 
 typedef enum
 #if __cplusplus >= 201103L
-    : uint8_t
+    : uint32_t
+#endif
+{
+  OSP_SPHERE = 50,
+  OSP_DISC = 51,
+  OSP_ORIENTED_DISC = 52,
+  OSP_UNKNOWN_SPHERE_TYPE = 255
+} OSPSphereType;
+
+typedef enum
+#if __cplusplus >= 201103L
+    : uint32_t
 #endif
 {
   OSP_LINEAR,
@@ -328,7 +355,7 @@ typedef enum
 
 typedef enum
 #if __cplusplus >= 201103L
-    : uint8_t
+    : uint32_t
 #endif
 {
   OSP_SUBDIVISION_NO_BOUNDARY,
@@ -341,7 +368,7 @@ typedef enum
 // AMR Volume rendering methods
 typedef enum
 #if __cplusplus >= 201103L
-    : uint8_t
+    : uint32_t
 #endif
 {
   OSP_AMR_CURRENT,
@@ -356,8 +383,8 @@ typedef enum
 #endif
 {
   OSP_VOLUME_FILTER_NEAREST = 0, // treating voxel cell as constant
-  OSP_VOLUME_FILTER_TRILINEAR = 100, // default trilinear interpolation
-  OSP_VOLUME_FILTER_TRICUBIC = 200 // tricubic interpolation
+  OSP_VOLUME_FILTER_LINEAR = 100, // default trilinear interpolation
+  OSP_VOLUME_FILTER_CUBIC = 200 // tricubic interpolation
 } OSPVolumeFilter;
 
 // VDB node data format
@@ -373,7 +400,7 @@ typedef enum
 // OSPRay pixel filter types
 typedef enum
 #if __cplusplus >= 201103L
-    : uint8_t
+    : uint32_t
 #endif
 {
   OSP_PIXELFILTER_POINT,
@@ -381,12 +408,12 @@ typedef enum
   OSP_PIXELFILTER_GAUSS,
   OSP_PIXELFILTER_MITCHELL,
   OSP_PIXELFILTER_BLACKMAN_HARRIS
-} OSPPixelFilterTypes;
+} OSPPixelFilterType;
 
 // OSPRay light quantity types
 typedef enum
 #if __cplusplus >= 201103L
-    : uint8_t
+    : uint32_t
 #endif
 {
   OSP_INTENSITY_QUANTITY_RADIANCE, // unit W/sr/m^2
@@ -396,3 +423,14 @@ typedef enum
   OSP_INTENSITY_QUANTITY_SCALE, // linear scaling factor for the built-in type
   OSP_INTENSITY_QUANTITY_UNKNOWN
 } OSPIntensityQuantity;
+
+// OSPRay quality levels (used for denoiser), same values as OIDN
+typedef enum
+#if __cplusplus >= 201103L
+    : uint32_t
+#endif
+{
+  OSP_DENOISER_QUALITY_LOW = 4,
+  OSP_DENOISER_QUALITY_MEDIUM = 5,
+  OSP_DENOISER_QUALITY_HIGH = 6
+} OSPDenoiserQuality;
