@@ -21,7 +21,9 @@ struct PanoramicCamera
 #ifdef __cplusplus
   PanoramicCamera()
       : org(0.f), frame(one), stereoMode(OSP_STEREO_NONE), ipd_offset(0.f)
-  {}
+  {
+    super.type = CAMERA_TYPE_PANORAMIC;
+  }
 };
 } // namespace ispc
 #else
