@@ -20,8 +20,7 @@ struct PerspectiveCamera
   // below are essentially unions: 1. if no motionBlur; 2. if motionBlur
   vec3f du_size; // delta of ray direction between two pixels in x, scaled to
                  // focusDistance; sensor size (in x and y) and architectural
-  vec3f dv_up; // delta of ray direction between two pixels in y, scaled to
-               // focusDistance; up direction of camera
+  vec3f dv_up; // up vector with magnitude equal to the imagePlane size in y
   vec3f ipd_offset; // shift of camera position for left/right eye (only when
                     // SIDE_BY_SIDE or TOP_BOTTOM); (0.5*ipd, focusDistance, 0)
 
@@ -43,7 +42,9 @@ struct PerspectiveCamera
         scaledAperture(0.f),
         aspect(1.f),
         stereoMode(OSP_STEREO_NONE)
-  {}
+  {
+    super.type = CAMERA_TYPE_PERSPECTIVE;
+  }
 };
 } // namespace ispc
 #else
