@@ -7,7 +7,6 @@
 #include <memory>
 #include "ISPCDeviceObject.h"
 #include "StructShared.h"
-#include "ispcrt.hpp"
 
 // including "Data_ispc.h" breaks app code using SDK headers
 #ifndef __ISPC_STRUCT_Data1D__
@@ -36,7 +35,9 @@ struct OSPRAY_SDK_INTERFACE Data : public ISPCDeviceObject
       const void *sharedData,
       OSPDataType,
       const vec3ul &numItems,
-      const vec3l &byteStride);
+      const vec3l &byteStride,
+      OSPDeleterCallback freeFunction = nullptr,
+      const void *userData = nullptr);
   Data(api::ISPCDevice &device, OSPDataType, const vec3ul &numItems);
 
   virtual ~Data() override;
@@ -69,7 +70,7 @@ struct OSPRAY_SDK_INTERFACE Data : public ISPCDeviceObject
 
  protected:
   // The actual buffer storing the data
-  std::unique_ptr<BufferShared<char>> view;
+  BufferSharedUq<char> view;
   char *addr{nullptr};
   // We need to track the appSharedPtr separately for the GPU backend, if we
   // were passed a shared ptr to memory that was not in USM we made a copy that
@@ -93,17 +94,27 @@ struct OSPRAY_SDK_INTERFACE Data : public ISPCDeviceObject
 
  private:
   void init(); // init dimensions and byteStride
+
+ protected:
+  OSPDeleterCallback freeFunction{nullptr};
+  const void *userData{nullptr};
 };
 
 OSPTYPEFOR_SPECIALIZATION(Data *, OSP_DATA);
 
 template <typename T>
-class Iter : public std::iterator<std::forward_iterator_tag, T>
+class Iter
 {
   const Data &data;
   vec3ul idx;
 
  public:
+  using iterator_category = std::forward_iterator_tag;
+  using value_type = T;
+  using difference_type = std::ptrdiff_t;
+  using pointer = T *;
+  using reference = T &;
+
   Iter(const Data &data, vec3ul idx) : data(data), idx(idx) {}
   Iter &operator++()
   {
@@ -133,12 +144,18 @@ class Iter : public std::iterator<std::forward_iterator_tag, T>
 };
 
 template <typename T>
-class Iter1D : public std::iterator<std::forward_iterator_tag, T>
+class Iter1D
 {
   char *addr{nullptr};
   int64_t byteStride{1};
 
  public:
+  using iterator_category = std::forward_iterator_tag;
+  using value_type = T;
+  using difference_type = std::ptrdiff_t;
+  using pointer = T *;
+  using reference = T &;
+
   Iter1D(char *addr, int64_t byteStride) : addr(addr), byteStride(byteStride) {}
   Iter1D &operator++()
   {
@@ -336,7 +353,7 @@ template <typename T, int DIM>
 inline const Ref<const DataT<T, DIM>> ISPCDeviceObject::getParamDataT(
     const char *name, bool required, bool promoteScalar)
 {
-  Data *data = getParam<Data *>(name);
+  Data *data = getParamObject<Data>(name);
 
   if (data && data->is<T, DIM>())
     return &(data->as<T, DIM>());
