@@ -5,6 +5,7 @@
 
 // ospray stuff
 #include "Data.h"
+#include "FeatureFlagsEnum.h"
 #include "ISPCDeviceObject.h"
 #include "StructShared.h"
 // stl
@@ -48,14 +49,23 @@ struct OSPRAY_SDK_INTERFACE Group
 #endif
   RTCScene sceneClippers{nullptr};
 
+  const FeatureFlags &getFeatureFlags() const;
+
  private:
-  std::unique_ptr<BufferShared<ispc::GeometricModel *>> geometricModelsArray;
+  FeatureFlags featureFlags;
+
+  BufferSharedUq<ispc::GeometricModel *> geometricModelsArray;
 #ifdef OSPRAY_ENABLE_VOLUMES
-  std::unique_ptr<BufferShared<ispc::VolumetricModel *>> volumetricModelsArray;
+  BufferSharedUq<ispc::VolumetricModel *> volumetricModelsArray;
 #endif
-  std::unique_ptr<BufferShared<ispc::GeometricModel *>> clipModelsArray;
+  BufferSharedUq<ispc::GeometricModel *> clipModelsArray;
 };
 
 OSPTYPEFOR_SPECIALIZATION(Group *, OSP_GROUP);
 
+inline const FeatureFlags &Group::getFeatureFlags() const
+{
+  return featureFlags;
+}
+
 } // namespace ospray
