@@ -22,23 +22,23 @@ struct SparseFB
   uint32 numTiles;
   // Image data for the tiles in this SparseFrameBuffer
   Tile *tiles;
-  // holds accumID per task region, for adaptive accumulation
-  int32 *taskAccumID;
-  // holds the accumulated color for each tile, tile's rgba stores the final
-  // color
-  vec4f *accumulationBuffer;
   // accumulates every other sample, for variance estimation / stopping
   vec4f *varianceBuffer;
   // holds error per task region, for adaptive accumulation
   float *taskRegionError;
+  // the dynamic loadbalancer accumulates not in the rendertask, but the owning
+  // rank accumulates the arriving tiles
+  bool accumulate;
 
 #ifdef __cplusplus
   SparseFB()
-      : tiles(nullptr),
-        taskAccumID(nullptr),
-        accumulationBuffer(nullptr),
+      : numRenderTasks(0),
+        totalTiles(0),
+        numTiles(0),
+        tiles(nullptr),
         varianceBuffer(nullptr),
-        taskRegionError(nullptr)
+        taskRegionError(nullptr),
+        accumulate(false)
   {
     super.type = FRAMEBUFFER_TYPE_SPARSE;
   }
