@@ -4,7 +4,7 @@
 #pragma once
 
 #include <vector>
-#include "common/BufferShared.h"
+#include "common/DeviceRT.h"
 #include "common/OSPCommon.h"
 #include "rkcommon/containers/AlignedVector.h"
 
@@ -16,7 +16,7 @@ namespace ospray {
 class OSPRAY_SDK_INTERFACE TaskError
 {
  public:
-  TaskError(ispcrt::Device &ispcrtDevice, const vec2i &numTasks);
+  TaskError(devicert::Device &device, const vec2i &numTasks);
 
   // The default constructor will make an empty task error region
   TaskError() = default;
@@ -36,7 +36,7 @@ class OSPRAY_SDK_INTERFACE TaskError
  protected:
   vec2i numTasks = vec2i(0);
   // holds error per task
-  std::unique_ptr<BufferShared<float>> taskErrorBuffer;
+  BufferSharedUq<float> taskErrorBuffer;
   // image regions (in #tasks) that do not yet estimate the error on
   // per-task basis
   std::vector<box2i> errorRegion;
