@@ -8,7 +8,7 @@ namespace ospray {
 
 struct OSPRAY_SDK_INTERFACE DebugFrameOp : public FrameOp
 {
-  DebugFrameOp(api::Device &device);
+  DebugFrameOp(devicert::Device &device);
 
   std::unique_ptr<LiveFrameOpInterface> attach(
       FrameBufferView &fbView) override;
@@ -18,11 +18,8 @@ struct OSPRAY_SDK_INTERFACE DebugFrameOp : public FrameOp
 
 struct OSPRAY_SDK_INTERFACE LiveDebugFrameOp : public LiveFrameOp
 {
-  LiveDebugFrameOp(api::ISPCDevice &device, FrameBufferView &fbView)
-      : LiveFrameOp(device, fbView)
-  {}
-
-  void process(void *waitEvent) override;
+  LiveDebugFrameOp(devicert::Device &device, FrameBufferView &fbView);
+  devicert::AsyncEvent process() override;
 };
 
 } // namespace ospray
