@@ -34,14 +34,18 @@ struct OSPRAY_SDK_INTERFACE GeometricModel
   bool hasEmissiveMaterials(
       Ref<const DataT<Material *>> rendererMaterials) const;
 
+  FeatureFlags getFeatureFlags() const;
+
  private:
   Ref<Geometry> geom;
   const Ref<Geometry> geomAPI;
   Ref<const Data> materialData;
   Ref<const DataT<vec4f>> colorData;
   Ref<const DataT<uint8_t>> indexData;
-  std::unique_ptr<BufferShared<ispc::Material *>> materialArray;
-  std::unique_ptr<BufferShared<uint32_t>> materialIDArray;
+  BufferSharedUq<ispc::Material *> materialArray;
+  BufferSharedUq<uint32_t> materialIDArray;
+
+  FeatureFlagsOther featureFlagsOther{FFO_NONE};
 };
 
 OSPTYPEFOR_SPECIALIZATION(GeometricModel *, OSP_GEOMETRIC_MODEL);
@@ -63,4 +67,11 @@ inline bool GeometricModel::invertedNormals() const
   return getSh()->invertedNormals;
 }
 
+inline FeatureFlags GeometricModel::getFeatureFlags() const
+{
+  FeatureFlags ff = geom->getFeatureFlags();
+  ff.other |= featureFlagsOther;
+  return ff;
+}
+
 } // namespace ospray
