@@ -11,9 +11,11 @@ namespace ospray {
  *  thus projects parallel rays of light across the entire scene */
 struct OSPRAY_SDK_INTERFACE DirectionalLight : public Light
 {
-  DirectionalLight(api::ISPCDevice &device) : Light(device) {}
+  DirectionalLight(api::ISPCDevice &device)
+      : Light(device, FFO_LIGHT_DIRECTIONAL)
+  {}
   virtual ~DirectionalLight() override = default;
-  virtual ISPCRTMemoryView createSh(
+  virtual ispc::Light *createSh(
       uint32_t, const ispc::Instance *instance = nullptr) const override;
   virtual std::string toString() const override;
   virtual void commit() override;
