@@ -12,9 +12,9 @@ namespace ospray {
  * area into the positive half space */
 struct OSPRAY_SDK_INTERFACE QuadLight : public Light
 {
-  QuadLight(api::ISPCDevice &device) : Light(device) {}
+  QuadLight(api::ISPCDevice &device) : Light(device, FFO_LIGHT_QUAD) {}
   virtual ~QuadLight() override = default;
-  virtual ISPCRTMemoryView createSh(
+  virtual ispc::Light *createSh(
       uint32_t, const ispc::Instance *instance = nullptr) const override;
   virtual std::string toString() const override;
   virtual void commit() override;
