@@ -3,15 +3,15 @@
 
 #pragma once
 
-#include "camera/Camera.h"
 #include "common/OSPCommon.h"
-#include "common/World.h"
-#include "fb/FrameBuffer.h"
 #include "render/Renderer.h"
-#include "rkcommon/utility/ArrayView.h"
 
 namespace ospray {
 
+struct FrameBuffer;
+struct Camera;
+struct World;
+
 struct OSPRAY_SDK_INTERFACE TiledLoadBalancer
 {
   virtual ~TiledLoadBalancer() = default;
@@ -21,7 +21,7 @@ struct OSPRAY_SDK_INTERFACE TiledLoadBalancer
   /*! Render the entire framebuffer using the given renderer, camera and
    * world configuration using the load balancer to parallelize the work
    */
-  virtual void renderFrame(
+  virtual std::pair<devicert::AsyncEvent, devicert::AsyncEvent> renderFrame(
       FrameBuffer *fb, Renderer *renderer, Camera *camera, World *world) = 0;
 };
 
@@ -34,19 +34,13 @@ struct OSPRAY_SDK_INTERFACE TiledLoadBalancer
   application ranks each doing local rendering on their own)  */
 struct OSPRAY_SDK_INTERFACE LocalTiledLoadBalancer : public TiledLoadBalancer
 {
-  void renderFrame(FrameBuffer *fb,
+  std::pair<devicert::AsyncEvent, devicert::AsyncEvent> renderFrame(
+      FrameBuffer *fb,
       Renderer *renderer,
       Camera *camera,
       World *world) override;
 
   std::string toString() const override;
-
-#ifdef OSPRAY_TARGET_SYCL
-  void setQueue(sycl::queue *syclQueue);
-
- private:
-  sycl::queue *syclQueue = nullptr;
-#endif
 };
 
 } // namespace ospray
