@@ -2,6 +2,7 @@
 // SPDX-License-Identifier: Apache-2.0
 
 #pragma once
+#include "texture/TextureParamShared.h"
 
 #define EPS 1e-5f
 
@@ -15,6 +16,7 @@ namespace ispc {
 typedef void *Material_GetBSDFFunc;
 typedef void *Material_GetTransparencyFunc;
 typedef void *Material_SelectNextMediumFunc;
+typedef void *Material_GetEmissionFunc;
 #else
 struct BSDF;
 struct ShadingContext;
@@ -22,8 +24,9 @@ struct Medium;
 struct DifferentialGeometry;
 struct Ray;
 struct Material;
+struct FeatureFlagsHandler;
 
-typedef const varying BSDF *varying (*Material_GetBSDFFunc)(
+typedef const varying BSDF *uniform (*Material_GetBSDFFunc)(
     const uniform Material *uniform self,
     uniform ShadingContext *uniform ctx,
     // The point to shade on a surface.
@@ -31,7 +34,8 @@ typedef const varying BSDF *varying (*Material_GetBSDFFunc)(
     // The ray arriving at the point to shade.
     const Ray &ray,
     // The medium this ray travels inside.
-    const Medium &currentMedium);
+    const Medium &currentMedium,
+    const uniform FeatureFlagsHandler &ffh);
 
 // shortcut: compute transmission of material, for transparent shadows,
 // neglecting refraction
@@ -42,12 +46,18 @@ typedef vec3f (*Material_GetTransparencyFunc)(
     // The ray arriving at the point to shade.
     const Ray &ray,
     // The medium this ray travels inside.
-    const Medium &currentMedium);
+    const Medium &currentMedium,
+    const uniform FeatureFlagsHandler &ffh);
 
 typedef void (*Material_SelectNextMediumFunc)(
     const uniform Material *uniform self,
     const DifferentialGeometry &dg,
     Medium &currentMedium);
+
+typedef vec3f (*Material_GetEmissionFunc)(const Material *uniform self,
+    // The point to shade on a surface.
+    const varying DifferentialGeometry &dg,
+    const uniform FeatureFlagsHandler &ffh);
 #endif
 
 enum MaterialType
@@ -74,18 +84,20 @@ struct Material
   Material_GetBSDFFunc getBSDF;
   Material_GetTransparencyFunc getTransparency;
   Material_SelectNextMediumFunc selectNextMedium;
-  vec3f emission; // simple constant (spatially and angular) emission, returns
-                  // radiance; TODO SV-EDFs
+  Material_GetEmissionFunc getEmission;
+
+  bool isEmissive;
 
   MicrofacetAlbedoTables *microfacetAlbedoTables;
 
 #ifdef __cplusplus
-  Material(const vec3f &emission = vec3f(0.f))
+  Material()
       : type(MATERIAL_TYPE_UNKNOWN),
         getBSDF(nullptr),
         getTransparency(nullptr),
         selectNextMedium(nullptr),
-        emission(emission),
+        getEmission(nullptr),
+        isEmissive(false),
         microfacetAlbedoTables(nullptr)
   {}
 };
