@@ -10,11 +10,16 @@ namespace pathtracer {
 
 struct Alloy : public AddStructShared<Material, ispc::Alloy>
 {
-  Alloy();
+  Alloy(api::ISPCDevice &device);
 
   virtual std::string toString() const override;
 
   virtual void commit() override;
+
+ private:
+  MaterialParam3f color;
+  MaterialParam3f edgeColor;
+  MaterialParam1f roughness;
 };
 
 } // namespace pathtracer
