@@ -10,12 +10,22 @@ namespace pathtracer {
 
 struct Luminous : public AddStructShared<Material, ispc::Luminous>
 {
-  Luminous();
+  Luminous(api::ISPCDevice &device);
 
   virtual std::string toString() const override;
 
   virtual void commit() override;
+
+  virtual bool isEmissive() const override;
+
+ private:
+  MaterialParam3f emissiveColor;
 };
 
+inline bool Luminous::isEmissive() const
+{
+  return reduce_max(getSh()->radiance) > 0.f;
+}
+
 } // namespace pathtracer
 } // namespace ospray
