@@ -11,11 +11,14 @@ namespace pathtracer {
 
 struct MetallicPaint : public AddStructShared<Material, ispc::MetallicPaint>
 {
-  MetallicPaint();
+  MetallicPaint(api::ISPCDevice &device);
 
   virtual std::string toString() const override;
 
   virtual void commit() override;
+
+ private:
+  MaterialParam3f color;
 };
 
 } // namespace pathtracer
