@@ -15,12 +15,11 @@ struct SciVis : public AddStructShared<Renderer, ispc::SciVis>
   void commit() override;
   void *beginFrame(FrameBuffer *, World *) override;
 
-  virtual AsyncEvent renderTasks(FrameBuffer *fb,
+  virtual devicert::AsyncEvent renderTasks(FrameBuffer *fb,
       Camera *camera,
       World *world,
       void *perFrameData,
-      const utility::ArrayView<uint32_t> &taskIDs,
-      bool wait) const override;
+      const utility::ArrayView<uint32_t> &taskIDs) const override;
 };
 
 } // namespace ospray
