@@ -5,6 +5,7 @@
 
 #include "Texture.h"
 #include "common/Data.h"
+#include "texture/MipMapCache.h"
 // ispc shared
 #include "Texture2DShared.h"
 
@@ -15,19 +16,21 @@ struct OSPRAY_SDK_INTERFACE Texture2D
     : public AddStructShared<Texture, ispc::Texture2D>
 {
   Texture2D(api::ISPCDevice &device)
-      : AddStructShared(device.getIspcrtDevice(), device)
+      : AddStructShared(device.getDRTDevice(), device)
   {}
-  virtual ~Texture2D() override = default;
+  ~Texture2D() override;
 
-  virtual std::string toString() const override;
+  std::string toString() const override;
 
-  virtual void commit() override;
+  void commit() override;
 
   OSPTextureFormat format{OSP_TEXTURE_FORMAT_INVALID};
-  OSPTextureFilter filter{OSP_TEXTURE_FILTER_BILINEAR};
+  OSPTextureFilter filter{OSP_TEXTURE_FILTER_LINEAR};
+  vec2ui wrapMode{OSP_TEXTURE_WRAP_REPEAT};
 
  protected:
   Ref<const Data> texData;
+  MipMapCache::BufferPtr mipMapData;
 };
 
 } // namespace ospray
