@@ -5,15 +5,14 @@
 #pragma once
 
 #include "ISPCDeviceObject.h"
+#include "common/FeatureFlagsEnum.h"
 #include "common/StructShared.h"
 // embree
 #include "common/Embree.h"
 // openvkl
 #include "openvkl/openvkl.h"
 // comment break to prevent clang-format from reordering openvkl includes
-#if OPENVKL_VERSION_MAJOR > 1
 #include "openvkl/device/openvkl.h"
-#endif
 // ispc shared
 #include "VolumeShared.h"
 
@@ -28,6 +27,8 @@ struct OSPRAY_SDK_INTERFACE Volume
   std::string toString() const override;
   void commit() override;
 
+  FeatureFlags getFeatureFlags() const;
+
  private:
   void checkDataStride(const Data *) const;
   void handleParams();
@@ -45,9 +46,18 @@ struct OSPRAY_SDK_INTERFACE Volume
   box3f bounds{empty};
 
   std::string vklType;
+
+  VKLFeatureFlags vklFeatureFlags = VKL_FEATURE_FLAGS_NONE;
 };
 
 OSPTYPEFOR_SPECIALIZATION(Volume *, OSP_VOLUME);
 
+inline FeatureFlags Volume::getFeatureFlags() const
+{
+  FeatureFlags ff;
+  ff.volume = vklFeatureFlags;
+  return ff;
+}
+
 } // namespace ospray
 #endif
