@@ -5,11 +5,11 @@
 #pragma once
 
 #include "Volume.h"
+#include "common/FeatureFlagsEnum.h"
 #include "openvkl/openvkl.h"
 // comment break to prevent clang-format from reordering openvkl includes
-#if OPENVKL_VERSION_MAJOR > 1
 #include "openvkl/device/openvkl.h"
-#endif
+#include "transferFunction/TransferFunction.h"
 // ispc shared
 #include "volume/VolumetricModelShared.h"
 
@@ -30,14 +30,26 @@ struct OSPRAY_SDK_INTERFACE VolumetricModel
 
   Ref<Volume> getVolume() const;
 
+  FeatureFlags getFeatureFlags() const;
+
  private:
   box3f volumeBounds;
   Ref<Volume> volume;
+  Ref<TransferFunction> transferFunction;
   const Ref<Volume> volumeAPI;
   VKLIntervalIteratorContext vklIntervalContext = VKLIntervalIteratorContext();
+
+  FeatureFlagsOther featureFlagsOther{FFO_VOLUME_IN_SCENE};
 };
 
 OSPTYPEFOR_SPECIALIZATION(VolumetricModel *, OSP_VOLUMETRIC_MODEL);
 
+inline FeatureFlags VolumetricModel::getFeatureFlags() const
+{
+  FeatureFlags ff = volume->getFeatureFlags();
+  ff.other |= featureFlagsOther;
+  return ff;
+}
+
 } // namespace ospray
 #endif
