@@ -1,10 +1,10 @@
 // Copyright 2021 Intel Corporation
 // SPDX-License-Identifier: Apache-2.0
+#ifdef OSPRAY_ENABLE_VOLUMES
 
 #pragma once
 
 #ifdef __cplusplus
-#include "common/StructShared.h"
 namespace ispc {
 #endif // __cplusplus
 
@@ -29,8 +29,8 @@ struct VolumetricModel
   VolumetricModel()
       : volume(nullptr),
         transferFunction(nullptr),
-        vklIntervalContext(nullptr),
-        boundingBox(0.f, 0.f),
+        vklIntervalContext(VKLIntervalIteratorContext()),
+        boundingBox(0.f),
         densityScale(1.f),
         anisotropy(0.f),
         gradientShadingScale(0.f),
@@ -41,3 +41,4 @@ struct VolumetricModel
 #else
 };
 #endif // __cplusplus
+#endif
