@@ -49,15 +49,12 @@ struct DistributedRaycastRenderer : public AddStructShared<DistributedRenderer,
       DistributedWorld *world,
       const box3f &region,
       void *perFrameData,
-      const utility::ArrayView<uint32_t> &taskIDs,
-      sycl::queue &syclQueue) const override;
+      const utility::ArrayView<uint32_t> &taskIDs) const override;
 #endif
 
  private:
   // The communicator to use for collectives in the renderer
   mpicommon::Group mpiGroup;
-
-  std::unique_ptr<std::ofstream> statsLog;
 };
 
 } // namespace mpi
